pub enum QueryMsg {
Ownership {},
Info {},
Distributable {
t: Option<Timestamp>,
},
Vested {
t: Option<Timestamp>,
},
TotalToVest {},
VestDuration {},
Stake(StakeTrackerQuery),
}Variants
Ownership
Get the current ownership.
Info
Returns information about the vesting contract and the status of the payment.
Distributable
Returns the number of tokens currently claimable by the vestee. This is the minimum of the number of unstaked tokens in the contract, and the number of tokens that have been vested at time t.
Vested
Gets the current value of vested(t). If t is None, the
current time is used.
TotalToVest
Gets the total amount that will ever vest, max(vested(t)).
Note that if the contract is canceled at time c, this value
will change to vested(c). Thus, it can not be assumed to be
constant over the contract’s lifetime.
VestDuration
Gets the amount of time between the vest starting, and it
completing. Returns None if the vest has been cancelled.
Stake(StakeTrackerQuery)
Queries information about the contract’s understanding of it’s
bonded and unbonding token balances. See the
StakeTrackerQuery in packages/cw-stake-tracker/lib.rs for
query methods and their return types.